@@ -1,9 +1,9 @@
 ## File Name: frm_mlreg_sample_parameters.R
-## File Version: 0.197
+## File Version: 0.200
 
 
 frm_mlreg_sample_parameters <- function(model, y, design_matrix,
-        R_args, ...)
+                R_args, ...)
 {
     #*** create new design matrices
     formula_terms <- model$formula_terms
@@ -48,11 +48,12 @@ frm_mlreg_sample_parameters <- function(model, y, design_matrix,
     ml_mcmc_fit_args <- list( y=y, X=X, Z_list=Z_list, beta=beta, Psi_list=Psi_list,
             sigma2=sigma2, alpha=alpha, u_list=u_list, idcluster_list=idcluster_list,
             onlyintercept_list=onlyintercept_list, ncluster_list=ncluster_list,
-            sigma2_nu0=sigma2_nu0, sigma2_sigma2_0=sigma2_sigma2_0, psi_nu0_list=psi_nu0_list,
-            psi_S0_list=psi_S0_list, est_sigma2=est_sigma2, est_probit=est_probit,
-            parameter_index=parameter_index, est_parameter=est_parameter, npar=npar,
-            iter=iter, save_iter=save_iter, verbose=verbose, print_iter=print_iter,
-            parnames0=parnames0, K=K, est_thresh=est_thresh, thresh_fac=thresh_fac,
+            sigma2_nu0=sigma2_nu0, sigma2_sigma2_0=sigma2_sigma2_0,
+            psi_nu0_list=psi_nu0_list, psi_S0_list=psi_S0_list, est_sigma2=est_sigma2,
+            est_probit=est_probit, parameter_index=parameter_index,
+            est_parameter=est_parameter, npar=npar, iter=iter, save_iter=save_iter,
+            verbose=verbose, print_iter=print_iter, parnames0=parnames0, K=K,
+            est_thresh=est_thresh, thresh_fac=thresh_fac,
             ridge=ridge, parm_summary=FALSE)
     res <- do.call( miceadds::ml_mcmc_fit, args=ml_mcmc_fit_args)
     sampled_values <- res$sampled_values
