@@ -1,5 +1,5 @@
 ## File Name: frm_prepare_data_include_latent_data.R
-## File Version: 0.21
+## File Version: 0.224
 
 
 ##################################################################
@@ -30,6 +30,14 @@ frm_prepare_data_include_latent_data <- function( dat, var_mm,
         dat11 <- dat0[ rep_ind,  ]
         dat11[,var_mm] <- rep( nodes_mm, each=N0 )
         dat11$weights <- dat11$weights * rep( ind_mm$nodes_weights, each=N0 )
+        #*** include delta_nodes for some models
+        model_mm <- ind_mm$model
+        models0 <- c("linreg", "yjtreg", "bctreg")
+        if (sum( model_mm %in% models0 )> 0 ){
+            d1 <- cbind( c( diff(nodes_mm), NA), c(NA, diff(nodes_mm) ) )
+            diff_nodes <- rowMeans(d1, na.rm=TRUE)
+            dat11$delta_nodes <- dat11$delta_nodes * rep( diff_nodes, each=N0 )
+        }
         dat12 <- rbind( dat12, dat11 )
     }
     dat12 <- dat12[ order(dat12$case), ]
