@@ -1,5 +1,5 @@
 ## File Name: mdmb_regression_oprobit_density.R
-## File Version: 0.28
+## File Version: 0.292
 
 mdmb_regression_oprobit_density <- function( y, ypred, thresh, log, eps=1E-50,
         max_val=99, use_rcpp=TRUE )
@@ -8,7 +8,8 @@ mdmb_regression_oprobit_density <- function( y, ypred, thresh, log, eps=1E-50,
     thresh_low <- c( -max_val, thresh)
     thresh_upp <- c( thresh, max_val )
     if ( ! use_rcpp ){
-        ll_i <- stats::pnorm( thresh_upp[y+1] - ypred ) - stats::pnorm( thresh_low[y+1] - ypred )
+        ll_i <- stats::pnorm( thresh_upp[y+1] - ypred ) -
+                        stats::pnorm( thresh_low[y+1] - ypred )
         if (log){
             ll_i <- log( ll_i + eps )
         }
